==> agora-0.5.23.zip: agora-0.5.23/agora/system/test/test_ufo_exchange.py <==
###############################################################################
#
#   Agora Portfolio & Risk Management System
#
#   Copyright 2015 Carlo Sbraccia
#
#   Licensed under the Apache License, Version 2.0 (the "License");
#   you may not use this file except in compliance with the License.
#   You may obtain a copy of the License at
#
#       http://www.apache.org/licenses/LICENSE-2.0
#
#   Unless required by applicable law or agreed to in writing, software
#   distributed under the License is distributed on an "AS IS" BASIS,
#   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
#   See the License for the specific language governing permissions and
#   limitations under the License.
#
###############################################################################

from onyx.core import GetVal

import agora.system.ufo_exchange as ufo_exchange
import unittest


###############################################################################
class UnitTest(unittest.TestCase):
    # -------------------------------------------------------------------------
    @classmethod
    def setUpClass(cls):
        ufo_exchange.prepare_for_test()

    def test_Code(self):
        self.assertEqual(GetVal("XNYS Exchange", "Code"), "US")
        self.assertEqual(GetVal("XLON Exchange", "Code"), "LN")
        self.assertEqual(GetVal("XEUR Exchange", "Code"), "EUX")


if __name__ == "__main__":
    from agora.corelibs.unittest_utils import AgoraTestRunner
    unittest.main(testRunner=AgoraTestRunner)

==> agora-0.6.4.zip: agora-0.6.4/agora/system/test/test_ufo_exchange.py <==
###############################################################################
#
#   Agora Portfolio & Risk Management System
#
#   Copyright 2015 Carlo Sbraccia
#
#   Licensed under the Apache License, Version 2.0 (the "License");
#   you may not use this file except in compliance with the License.
#   You may obtain a copy of the License at
#
#       http://www.apache.org/licenses/LICENSE-2.0
#
#   Unless required by applicable law or agreed to in writing, software
#   distributed under the License is distributed on an "AS IS" BASIS,
#   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
#   See the License for the specific language governing permissions and
#   limitations under the License.
#
###############################################################################

from onyx.core import GetVal

import agora.system.ufo_exchange as ufo_exchange
import unittest


###############################################################################
class UnitTest(unittest.TestCase):
    # -------------------------------------------------------------------------
    @classmethod
    def setUpClass(cls):
        ufo_exchange.prepare_for_test()

    def test_Code(self):
        self.assertEqual(GetVal("XNYS Exchange", "Code"), "US")
        self.assertEqual(GetVal("XLON Exchange", "Code"), "LN")
        self.assertEqual(GetVal("XEUR Exchange", "Code"), "EUX")


if __name__ == "__main__":
    from onyx.core import TestRunner
    unittest.main(testRunner=TestRunner)
